package Bubblegum::Object::Float;

use Bubblegum::Class 'with';
use Bubblegum::Constraints -types;

with 'Bubblegum::Object::Role::Value';

our $VERSION = '0.20'; # VERSION

# needs formatting routines ... not implemented

1;
